@@ -1,6 +1,6 @@
 --[[
 
-File l3build-tagging.lua Copyright (C) 2018 The LaTeX3 Project
+File l3build-tagging.lua Copyright (C) 2018-2021 The LaTeX Project
 
 It may be distributed and/or modified under the conditions of the
 LaTeX Project Public License (LPPL), either version 1.3c of this
@@ -28,7 +28,7 @@ local os_date = os.date
 local match   = string.match
 local gsub    = string.gsub
 
-update_tag = update_tag or function(filename,content,tagname,tagdate)
+function update_tag(filename,content,tagname,tagdate)
   return content
 end
 
@@ -51,7 +51,7 @@ local function update_file_tag(file,tagname,tagdate)
   else
     local path = dirname(file)
     ren(path,filename,filename .. ".bak")
-    local f = assert(open(file,"w"))
+    f = assert(open(file,"w"))
     -- Convert line ends back if required during write
     -- Watch for the second return value!
     f:write((gsub(updated_content,"\n",os_newline)))
@@ -71,8 +71,8 @@ function tag(tagnames)
   local errorlevel = 0
   for _,dir in pairs(dirs) do
     for _,filetype in pairs(tagfiles) do
-      for file,_ in pairs(tree(dir,filetype)) do
-        errorlevel = update_file_tag(dir .. "/" .. file,tagname,tagdate)
+      for _,p in ipairs(tree(dir,filetype)) do
+        errorlevel = update_file_tag(dir .. "/" .. p.src,tagname,tagdate)
         if errorlevel ~= 0 then
           return errorlevel
         end
@@ -81,4 +81,3 @@ function tag(tagnames)
   end
   return tag_hook(tagname,tagdate)
 end
-
